@@ -6,12 +6,12 @@
 # \description{
 #  @classhierarchy
 #
-#  The System class contains several useful class fields and methods. It 
+#  The System class contains several useful class fields and methods. It
 #  cannot be instantiated.
 # }
 #
 # \section{Fields and Methods}{
-#  @allmethods  
+#  @allmethods
 # }
 #
 # @author
@@ -28,7 +28,7 @@ setConstructorS3("System", function() {
 # @title "Retrieves the computer name of the current host"
 #
 # \description{
-#  @get "title". 
+#  @get "title".
 # }
 #
 # @synopsis
@@ -36,10 +36,10 @@ setConstructorS3("System", function() {
 # \value{
 #  Returns a @character string.
 # }
-# 
+#
 # \details{
 #  First, this function checks the system environment variables \code{HOST},
-#  \code{HOSTNAME}, and \code{COMPUTERNAME}. 
+#  \code{HOSTNAME}, and \code{COMPUTERNAME}.
 #  Second, it checks \code{Sys.info()["nodename"]} for host name details.
 #  Finally, it tries to query the system command \code{uname -n}.
 # }
@@ -70,7 +70,7 @@ setMethodS3("getHostname", "System", function(static, ...) {
 # @title "Retrieves the name of the user running R"
 #
 # \description{
-#  @get "title". 
+#  @get "title".
 # }
 #
 # @synopsis
@@ -78,7 +78,7 @@ setMethodS3("getHostname", "System", function(static, ...) {
 # \value{
 #  Returns a @character string.
 # }
-# 
+#
 # \details{
 #  First, this function checks the system environment variables \code{USER},
 #  and \code{USERNAME}.
@@ -209,7 +209,7 @@ setMethodS3("parseDebian", "System", function(this, text=NULL, file=NULL, keys=N
   pkeys <- substring(text[keyLines], 1, keyLengths);
   text[keyLines] <- substring(text[keyLines], keyLengths+2);
   valueNbrOfLines <- c(keyLines, 0) - c(0, keyLines);
-  valueNbrOfLines <- valueNbrOfLines[-length(valueNbrOfLines)];	
+  valueNbrOfLines <- valueNbrOfLines[-length(valueNbrOfLines)];
   valueNbrOfLines <- valueNbrOfLines[-1];
   len <- length(valueNbrOfLines);
   valueNbrOfLines[len+1] <- keyLines[len+1]-length(text)+1;
@@ -224,18 +224,18 @@ setMethodS3("parseDebian", "System", function(this, text=NULL, file=NULL, keys=N
   # Some cleanup of values
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # 1. Replace all '\r' with '\n'.
-  values <- gsub("\r", "\n", values);  
+  values <- gsub("\r", "\n", values);
   # 2. At the end of each line, remove all whitespaces and add a space.
-  values <- gsub("[ \t]*\n", " \n", values);  
+  values <- gsub("[ \t]*\n", " \n", values);
   # 3. At the beginning of each line, remove all whitespaces.
-  values <- gsub("\n[ \t]*", "\n", values);  
+  values <- gsub("\n[ \t]*", "\n", values);
   # 4. Replace all lines that contains a single '.' with '\r'.
-  values <- gsub("\n[.] \n", "\n\r\n", values);  
+  values <- gsub("\n[.] \n", "\n\r\n", values);
   values <- gsub("\n[.] \n", "\n\r\n", values);  # since we miss every second!
   # 4. Remove all '\n'.
-  values <- gsub("\n", "", values);  
+  values <- gsub("\n", "", values);
   # 1. Replace all '\r' with '\n' (single '.' lines).
-  values <- gsub("\r", "\n", values);  
+  values <- gsub("\r", "\n", values);
   # 4. Removes prefix whitespaces
   values <- gsub("^[ \t]", "", values);
   # 5. Removes suffix whitespaces
@@ -246,7 +246,7 @@ setMethodS3("parseDebian", "System", function(this, text=NULL, file=NULL, keys=N
   values[nchar(values) == 0] <- " ";
   values <- gsub("[ \t]*$", "", values);
 
-  
+
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Return the wanted parameters
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -258,7 +258,7 @@ setMethodS3("parseDebian", "System", function(this, text=NULL, file=NULL, keys=N
     parameters <- as.list(values[idx]);
     names(parameters) <- pkeys[idx];
   }
-  
+
   parameters;
 }, static=TRUE);
 
@@ -290,7 +290,7 @@ setMethodS3("parseDebian", "System", function(this, text=NULL, file=NULL, keys=N
 # }
 #
 # \value{
-#   Returns the url of the \code{query}.  
+#   Returns the url of the \code{query}.
 # }
 #
 # \details{
@@ -333,9 +333,9 @@ setMethodS3("parseDebian", "System", function(this, text=NULL, file=NULL, keys=N
 # }
 #*/###########################################################################
 setMethodS3("openBrowser", "System", function(this, query, ...) {
-  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - 
+  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Local functions
-  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - 
+  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   startsWith <- function(prefix, s, ...) {
     res <- regexpr(paste("^", prefix, sep=""), as.character(s));
     (res[[1]] != -1);
@@ -375,7 +375,7 @@ setMethodS3("openBrowser", "System", function(this, query, ...) {
     first <- 1;
     tmp <- tolower(url);
 
-    if (is.null(browser) && 
+    if (is.null(browser) &&
       !startsWith(tmp, "http:") && !startsWith(tmp, "file:") &&
         !endsWith(tmp, ".html") && !endsWith(tmp, ".htm")) {
       first <- 2;
@@ -414,7 +414,7 @@ setMethodS3("openBrowser", "System", function(this, query, ...) {
       if (!loaded)
         shell.exec(url);
     }
-  }  
+  }
   # ---------------------------------------------------------------------
   # U n i x
   # ---------------------------------------------------------------------
@@ -443,26 +443,29 @@ setMethodS3("openBrowser", "System", function(this, query, ...) {
 #########################################################################/**
 # @RdocMethod findGhostscript
 #
-# @title "Searches for the ghostview binary on the current system"
+# @title "Searches for a Ghostview executable on the current system"
 #
 # \description{
-#   @get "title". 
-#  
+#   @get "title".
+#
 #   Currently only Windows and Unix is supported.
 # }
 #
 # @synopsis
 #
 # \arguments{
-#   \item{updateRGSCMD}{If @TRUE and ghostscript is found, then the system
-#     environment variable \code{R_GSCMD} is set to the (first) path found. 
+#   \item{updateRGSCMD}{If @TRUE and Ghostscript is found, then the system
+#     environment variable \code{R_GSCMD} is set to the (first) path found.
 #     This variable is used by the \code{bitmap()} device.}
+#   \item{firstOnly}{If @TRUE, only the first executable is returned.}
+#   \item{force}{If @TRUE, existing \code{R_GSCMD} is ignored, otherwise not.}
 #   \item{...}{Not used.}
 # }
 #
 #
 # \value{
-#   Returns a @vector of full pathnames where ghostscript is found. 
+#   Returns a @character @vector of full pathnames where Ghostscript
+#   executable are found.
 # }
 #
 # \examples{\dontrun{
@@ -477,58 +480,81 @@ setMethodS3("openBrowser", "System", function(this, query, ...) {
 #   @seeclass
 # }
 #*/#########################################################################
-setMethodS3("findGhostscript", "System", function(static, updateRGSCMD=TRUE, ...) {
-  pathname <- NULL;
+setMethodS3("findGhostscript", "System", function(static, updateRGSCMD=TRUE, firstOnly=TRUE, force=FALSE, ...) {
+  pathname <- Sys.getenv("R_GSCMD", "");
+  if (pathname == "") pathname <- NULL;
+
+  if (!force && isFile(pathname)) {
+    return(pathname);
+  }
 
   paths0 <- NULL;
 
   OST <- .Platform$OS.type;
   if (OST == "windows") {
-    # Default installation is "C:\gs\gs8.15\bin\gswin32c.exe";
+    # First, search executable on the system PATH
+    pathname <- Sys.which(c("gswin64c", "gswin32c"));
+    pathname <- pathname[nchar(pathname) > 0L];
+    pathname <- pathname[sapply(pathname, FUN=isFile)];
 
-    # Look for GS in <some path>/gs/, where <some path> is:
+    # Second, search known locations
+    if (length(pathname) == 0L) {
+      # Default installation is "C:\gs\gs{<ver>}\bin\gswin{32|64}c.exe";
 
-    # ...C:/ and/or whatever the system drive is...
-    systemDrives <- unique(c("C:", Sys.getenv("SystemDrive")));
-    systemDrives <- systemDrives[nchar(systemDrives) > 0];
+      # Look for GS in <some path>/gs/, where <some path> is:
+      # ...C:/ and/or whatever the system drive is...
+      systemDrives <- unique(c("C:", Sys.getenv("SystemDrive")));
+      systemDrives <- systemDrives[nchar(systemDrives) > 0L];
 
-    # ...or some of the 'Program Files' directories...
-    pfDirs <- Sys.getenv(c("ProgramFiles", "PROGRAMFILES_SHORT", 
+      # ...or some of the 'Program Files' directories...
+      pfDirs <- Sys.getenv(c("ProgramFiles", "PROGRAMFILES_SHORT",
                                                    "CommonProgramFiles"));
 
-    # Get all possible paths
-    paths0 <- sapply(systemDrives, FUN=function(systemDrive) {
-      file.path(c(systemDrive, pfDirs), "gs");
-    })
-    paths0 <- unlist(paths0, use.names=FALSE);
+      # Get all possible paths
+      paths0 <- sapply(systemDrives, FUN=function(systemDrive) {
+        file.path(c(systemDrive, pfDirs), "gs");
+      });
+      paths0 <- unlist(paths0, use.names=FALSE);
 
-    # Keep only those that are directories
-    paths <- paths0[file.exists(paths0)];  # Avoids warnings
-    if (length(paths) > 0)
-      paths <- paths[sapply(paths, FUN=isDirectory)];
+      # Keep only those that are directories
+      paths <- paths0[file.exists(paths0)];  # Avoids warnings
+      if (length(paths) > 0L) {
+        paths <- paths[sapply(paths, FUN=isDirectory)];
+      }
 
-    # Now search each of them for an ghostscript executable
-    pattern <- "gswin32c.exe$";
-    for (path in paths) {
-      pathname <- list.files(pattern=pattern, path=path, recursive=TRUE, 
+      # Now search each of them for an Ghostscript executable
+      pattern <- "gswin(32|64)c.exe$";
+      for (path in paths) {
+        pathname <- list.files(pattern=pattern, path=path, recursive=TRUE,
                                                           full.names=TRUE);
-      if (length(pathname) > 0)
-        break;
-    } # for (path ...)
-  } else if (OST == "unix") {
-    pathname <- system("which gs", intern=TRUE);
+        pathname <- pathname[sapply(pathname, FUN=isFile)];
+        if (length(pathname) > 0L) {
+          break;
+        }
+      } # for (path ...)
+    }
   } else {
-    warning("Unsupported operating system: ", OST);   
-    return(NULL);
+    pathname <- Sys.which("gs");
+    pathname <- pathname[nchar(pathname) > 0L];
+    pathname <- pathname[sapply(pathname, FUN=isFile)];
   }
 
-  if (length(pathname) > 0) {
-    if (length(pathname) > 1)
-      pathname <- pathname[1];
-    Sys.setenv("R_GSCMD"=pathname);
+  if (length(pathname) > 0L) {
+    if (firstOnly) {
+      pathname <- pathname[1L];
+    }
+    if (updateRGSCMD) {
+      pathnameT <- pathname[1L];
+      if (OST == "windows" && exists("shortPathName", mode="function")) {
+        # To please R CMD check
+        shortPathName <- NULL; rm(list="shortPathName");
+        pathnameT <- shortPathName(pathnameT);
+      }
+      Sys.setenv("R_GSCMD"=pathnameT);
+    }
   } else if (updateRGSCMD) {
     if (!is.null(paths0)) {
-      warning("Ghostscript not found. Searched directories: ", 
+      warning("Ghostscript not found. Searched directories: ",
                                              paste(paths0, collapse=", "));
     } else {
       warning("Ghostscript not found.");
@@ -543,7 +569,7 @@ setMethodS3("findGhostscript", "System", function(static, updateRGSCMD=TRUE, ...
 # @RdocMethod findGraphicsDevice
 #
 # @title "Searches for a working PNG device"
-# 
+#
 # \description{
 #  @get "title".
 #
@@ -554,10 +580,10 @@ setMethodS3("findGhostscript", "System", function(static, updateRGSCMD=TRUE, ...
 #
 #  Moreover, if identical looking bitmap and vector graphics (EPS) files
 #  are wanted for the same figures, in practice, \code{bitmap()} has
-#  to be used.  
+#  to be used.
 #
-#  By default, this method tests a list of potential graphical devices and 
-#  returns the first that successfully creates an image file.  
+#  By default, this method tests a list of potential graphical devices and
+#  returns the first that successfully creates an image file.
 #  By default, it tries to create a PNG image file via the built-in
 #  \code{png()} device.
 # }
@@ -569,10 +595,10 @@ setMethodS3("findGhostscript", "System", function(static, updateRGSCMD=TRUE, ...
 #     tested.}
 #   \item{maxCount}{The maximum number of subsequent tests for the
 #     the existances of \code{bitmap()} generated image files.}
-#   \item{sleepInterval}{The time in seconds between above subsequent 
+#   \item{sleepInterval}{The time in seconds between above subsequent
 #     tests.}
-#   \item{findGhostscript}{If @TRUE, ghostscript, which is needed by
-#     the \code{bitmap()} device, is searched for on the current system.  
+#   \item{findGhostscript}{If @TRUE, Ghostscript, which is needed by
+#     the \code{bitmap()} device, is searched for on the current system.
 #     If found, its location is recorded.}
 #   \item{...}{Not used.}
 # }
@@ -580,7 +606,7 @@ setMethodS3("findGhostscript", "System", function(static, updateRGSCMD=TRUE, ...
 # \value{
 #  Returns a @function that generates images, or @NULL.
 # }
-# 
+#
 # @author
 #
 # \examples{
@@ -603,7 +629,7 @@ setMethodS3("findGhostscript", "System", function(static, updateRGSCMD=TRUE, ...
 # }
 #
 # @keyword device
-#*/######################################################################### 
+#*/#########################################################################
 setMethodS3("findGraphicsDevice", "System", function(static, devices=list(png), maxCount=100, sleepInterval=0.1, findGhostscript=TRUE, ...) {
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Validate arguments
@@ -612,7 +638,7 @@ setMethodS3("findGraphicsDevice", "System", function(static, devices=list(png),
   devices <- as.list(devices);
   for (device in devices) {
     if (!is.function(device)) {
-      throw("Argument 'devices' specifies a non-function element: ", 
+      throw("Argument 'devices' specifies a non-function element: ",
                                                               mode(device));
     }
   }
@@ -665,26 +691,26 @@ setMethodS3("findGraphicsDevice", "System", function(static, devices=list(png),
       dev.off();
 
       # The following wait-and-poll code is typically only necessary for
-      # the bitmap() device since it calls ghostscript, which is called
+      # the bitmap() device since it calls Ghostscript, which is called
       # without waiting for it to finish.  The default is to poll for the
       # dummy image file for 10 seconds in intervals of 0.1 seconds.
       # If not found by then, the device is considered not to be found.
       # Hopefully, this is never the case.
-      count <- 0;
+      count <- 0L;
       while (count < maxCount) {
         if (file.exists(file)) {
           size <- file.info(file)$size;
-          if (!is.na(size) && size > 0) {
+          if (!is.na(size) && size > 0L) {
             return(device);
           }
         }
         Sys.sleep(sleepInterval);
-        count <- count + 1;
+        count <- count + 1L;
       }
     }, error = function(error) {
     });
   } # for (device in ...)
-  
+
   NULL;
 }, static=TRUE)
 
@@ -694,7 +720,7 @@ setMethodS3("mapDriveOnWindows", "System", function(static, drive, path=getwd(),
   # Local functions
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   isWindowsUncPath <- function(path, ...) {
-    (regexpr("^(//|\\\\)", path) != -1);
+    (regexpr("^(//|\\\\)", path) != -1L);
   } # isWindowsUncPath()
 
   getWindowsDrivePattern <- function(fmtstr, ...) {
@@ -710,13 +736,13 @@ setMethodS3("mapDriveOnWindows", "System", function(static, drive, path=getwd(),
   # Validate arguments
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Argument 'drive':
-  drive <- Arguments$getCharacter(drive, length=c(1,1), nchar=2);
+  drive <- Arguments$getCharacter(drive, length=c(1L,1L), nchar=2L);
   pattern <- getWindowsDrivePattern("[%s]:");
-  if (regexpr(pattern, toupper(drive)) == -1) {
+  if (regexpr(pattern, toupper(drive)) == -1L) {
     drive0 <- drive;
     # Add a colon, in case user forgot
     drive <- sprintf("%s:", drive);
-    if (regexpr(pattern, toupper(drive)) == -1) {
+    if (regexpr(pattern, toupper(drive)) == -1L) {
       throw("Argument 'drive' is not a valid drive (e.g. 'Y:'): ", drive0);
     }
   }
@@ -748,7 +774,7 @@ setMethodS3("mapDriveOnWindows", "System", function(static, drive, path=getwd(),
     return(invisible(newPath));
   }
 
-  # UNC paths should be mapped by 'net', 
+  # UNC paths should be mapped by 'net',
   # cf. http://support.microsoft.com/kb/218740
   if (isWindowsUncPath(path)) {
     # Map using 'net use', which:
@@ -756,7 +782,7 @@ setMethodS3("mapDriveOnWindows", "System", function(static, drive, path=getwd(),
     pathT <- gsub("/", "\\", path, fixed=TRUE);
     cmd <- sprintf("net use %s \"%s\"", toupper(drive), pathT);
     res <- system(cmd, intern=FALSE);
-    if (res != 0) {
+    if (res != 0L) {
       res <- "???";
       throw(sprintf("Failed to map drive '%s' to path '%s': %s (using '%s')",
                                                      drive, path, res, cmd));
@@ -765,7 +791,7 @@ setMethodS3("mapDriveOnWindows", "System", function(static, drive, path=getwd(),
     # Map using 'subst'
     cmd <- sprintf("subst %s \"%s\"", toupper(drive), path);
     res <- system(cmd, intern=TRUE);
-    if (length(res) > 0) {
+    if (length(res) > 0L) {
       throw(sprintf("Failed to map drive '%s' to path '%s': %s (using '%s')",
                                                      drive, path, res, cmd));
     }
@@ -783,7 +809,7 @@ setMethodS3("unmapDriveOnWindows", "System", function(static, drive, ...) {
   # Local functions
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   isWindowsUncPath <- function(path, ...) {
-    (regexpr("^(//|\\\\)", path) != -1);
+    (regexpr("^(//|\\\\)", path) != -1L);
   } # isWindowsUncPath()
 
   getWindowsDrivePattern <- function(fmtstr, ...) {
@@ -799,13 +825,13 @@ setMethodS3("unmapDriveOnWindows", "System", function(static, drive, ...) {
   # Validate arguments
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Argument 'drive':
-  drive <- Arguments$getCharacter(drive, length=c(1,1), nchar=2);
+  drive <- Arguments$getCharacter(drive, length=c(1L,1L), nchar=2L);
   pattern <- getWindowsDrivePattern("[%s]:");
-  if (regexpr(pattern, toupper(drive)) == -1) {
+  if (regexpr(pattern, toupper(drive)) == -1L) {
     drive0 <- drive;
     # Add a colon, in case user forgot
     drive <- sprintf("%s:", drive);
-    if (regexpr(pattern, toupper(drive)) == -1) {
+    if (regexpr(pattern, toupper(drive)) == -1L) {
       throw("Argument 'drive' is not a valid drive (e.g. 'Y:'): ", drive);
     }
   }
@@ -822,7 +848,7 @@ setMethodS3("unmapDriveOnWindows", "System", function(static, drive, ...) {
     # Unmap using 'net use'
     cmd <- sprintf("net use /delete \"%s\"", toupper(drive));
     res <- system(cmd, intern=FALSE);
-    if (res != 0) {
+    if (res != 0L) {
       res <- "???";
       throw(sprintf("Failed to unmap drive '%s': %s (using '%s')",
                                                      drive, res, cmd));
@@ -831,7 +857,7 @@ setMethodS3("unmapDriveOnWindows", "System", function(static, drive, ...) {
     # Unmap using 'subst'
     cmd <- sprintf("subst \"%s\" /D", toupper(drive));
     res <- system(cmd, intern=TRUE);
-    if (length(res) > 0) {
+    if (length(res) > 0L) {
       throw(sprintf("Failed to unmap drive '%s': %s (using '%s')",
                                                      drive, res, cmd));
     }
@@ -866,7 +892,7 @@ setMethodS3("getMappedDrivesOnWindows", "System", function(static, ...) {
   paths <- gsub("\\", "/", paths, fixed=TRUE);
 
   # Order by drive letters
-  if (length(paths) > 1) {
+  if (length(paths) > 1L) {
     o <- order(names(paths));
     paths <- paths[o];
   }
@@ -877,6 +903,11 @@ setMethodS3("getMappedDrivesOnWindows", "System", function(static, ...) {
 
 ############################################################################
 # HISTORY:
+# 2013-07-27
+# o On Windows, System$findGhostscript() sets R_GSCMD as shortPathName().
+# o Added arguments 'firstOnly' and 'force' to System$findGhostscript().
+# o Now System$findGhostscript() also searches for 'gswin64c.exe' in
+#   addition to 'gswin32c.exe' on Windows.  It also utilizes Sys.which().
 # 2012-07-10
 # o  System$findGraphicsDevice() no longer tries to create a PNG device
 #    using png2(), because that has now moved to R.devices.
@@ -886,10 +917,10 @@ setMethodS3("getMappedDrivesOnWindows", "System", function(static, ...) {
 #   This avoids returning devices that generates empty image files.
 #   Also updated the time out to 10 secs (was 30 secs).
 # 2011-09-19
-# o Now System$getMappedDrivesOnWindows() always returns paths with 
+# o Now System$getMappedDrivesOnWindows() always returns paths with
 #   forward slashes and handles drive letters mapped by both 'subst'
 #   and 'net use'.
-# o Now System$mapDriveOnWindows() can also map Windows UNC path 
+# o Now System$mapDriveOnWindows() can also map Windows UNC path
 #   (i.e. network resource).  This was triggered by a discussion with
 #   Keith Jewell at Campden BRI Group, UK.
 # o Now System$mapDriveOnWindows() and System$unmapDriveOnWindows()
@@ -904,7 +935,7 @@ setMethodS3("getMappedDrivesOnWindows", "System", function(static, ...) {
 # o Added System$mapDriveOnWindows(), System$unmapDriveOnWindows(), and
 #   System$getMappedDrivesOnWindows().
 # 2007-06-09
-# o BUG FIX: Used omit.na() instead of na.omit() in static method 
+# o BUG FIX: Used omit.na() instead of na.omit() in static method
 #   parseDebian() of System.
 # 2007-04-12
 # o BUG FIX: findGhostscript() would give error "paste(path0, collapse = ",
@@ -915,7 +946,7 @@ setMethodS3("getMappedDrivesOnWindows", "System", function(static, ...) {
 # 2007-04-07
 # o Removed never needed require(R.io) in openBrowser() for System.
 # 2007-01-22
-# o Replaced Sys.putenv() with new Sys.setenv(). 
+# o Replaced Sys.putenv() with new Sys.setenv().
 # 2007-01-10
 # o Now findGhostscript() searches all 'Program Files' directories too, if
 #   on Windows.
@@ -928,25 +959,25 @@ setMethodS3("getMappedDrivesOnWindows", "System", function(static, ...) {
 # 2005-09-18
 # o Renamed findPngDevice() to findGraphicsDevice(), but it still defaults
 #   to search for a PNG device.
-# o Added arguments 'maxCount', 'sleepInterval' and 'findGhostscript' to 
+# o Added arguments 'maxCount', 'sleepInterval' and 'findGhostscript' to
 #   findPngDevice().
 # 2005-09-16
-# o Added static findPngDevice() to System.  
-#   Added argument 'devices' to findPngDevice() so it is possible to 
+# o Added static findPngDevice() to System.
+#   Added argument 'devices' to findPngDevice() so it is possible to
 #   specify in which order PNG devices should be tested.  Now bitmap() and
 #   png() is tested by default.
 # 2005-07-18
 # o Example for parseDebian() used package R.lang. Fixed.
 # 2005-05-29
 # o Removed many unecessary (never used) methods and fields from the class:
-#   fields 'inn', 'err' and 'out' with corresponding methods setIn(), 
+#   fields 'inn', 'err' and 'out' with corresponding methods setIn(),
 #   setErr() and setOut(). In addition, indentityHashCode() getenv(), gc(),
 #   exit(), stop(), getProperties(), and getProperty() were removed.
 # o Moved System from R.lang to R.utils.
 # 2005-03-07
 # o Added static method findGhostscript().
 # 2004-07-25
-# o Added getUsername() and getHostname(). This was formerly in 
+# o Added getUsername() and getHostname(). This was formerly in
 #   R.jobs::Jobs, but is better suited here.
 # 2003-04-16
 # o Updated the Rdocs.
